<?php
/**
 * Ef Practical Social Widget.
 *
 * @package Ef Practical
 */

/**
 * Widget class.
 */
if ( ! class_exists( 'Practical_Social_Widget' ) ) {
	class Practical_Social_Widget extends WP_Widget {
        
		/**
		 * Register widget
		 */
		public function __construct() {
            $widget_ops = array(
                'classname' => 'ef_social_widget',
                'description' => esc_html__( 'Display social icons.', 'ef-practical' ),
            );
    		parent::__construct( 'practical_social_widget', esc_html__( 'Practical: Social', 'ef-practical' ), $widget_ops );
		}
		
		/**
		 * Output the content of the widget
		 */
		public function widget( $args, $instance ) {
            
			// Get social
			$socials = isset( $instance['socials'] ) ? $instance['socials'] : '';
            
			// return if null
			if ( ! $socials ) {
				return;
			}
            
			// vars
			$output = '';
			$title = ! empty( $instance['title'] ) ? $instance['title'] : '';
			$title = apply_filters( 'widget_title', $title, $instance, $this->id_base );
			$target = isset( $instance['target'] ) ? $instance['target'] : 0;
            $show	= isset( $instance['show'] ) ? $instance['show'] : 'icon';
			
			// Before widget
			$output .= $args['before_widget'];
            
			// Widget title
			if ( $title ) {
				$output .= $args['before_title'];
					$output .= $title;
				$output .= $args['after_title'];
			}
            
            // Target
            if ( $target ) {
                $new_tab = 'target="_blank"';
            } else {
                $new_tab = '';
            }
			
			$output .= '<div class="ef-social-widget ef-social-'. esc_attr( $show ) .'">';
                
				foreach( $socials as $key => $network ) {
                    
					$link = ! empty( $network['url'] ) ? esc_url( $network['url'] ) : '';
					$name = $network['name'];
                    
                    if ( 'icon' == $show ) {
                        $icon_text = '<i class="fa fa-'.strtolower( $name ).'"></i>';
                    } elseif ( 'text' == $show ) {
                        $icon_text = '<div class="text-social-widget">'. esc_html( $name ) .'</div>';
                    } else {
                        $icon_text = '<i class="fa fa-'.strtolower( $name ).'"></i><div class="text-social-widget">'.esc_html( $name ).'</div>';
                    }
                    
					if ( $link ) {
				        $output .= '<a class="social-icon '.esc_attr( strtolower( $name ) ).'" href="'.esc_url( $link ).'" '.$new_tab.' rel="nofollow">'.$icon_text.'<span></span></a>';
					}
                    
				}
                
			$output .= '</div>';
            
			// After widget
			$output .= $args['after_widget'];
            
			// output echo
			echo $output; // WPCS: XSS ok.
            
		}
        
		/**
		 *  Update the information in the WordPress database
		 */	
		public function update( $new_instance, $old_instance ) {
			$instance = $old_instance;
			$instance['socials'] = sanitize_text_field( $new_instance['socials'] );
            $instance['title']   = ( ! empty( $new_instance['title'] ) ) ? sanitize_text_field( $new_instance['title'] ) : '';
			$instance['target']  = ! empty( $new_instance['target'] ) ? true : false;
            $instance['show']    = ! empty( $new_instance['show'] ) ? sanitize_text_field( $new_instance['show'] ) : 'icon';
			return $instance;
		}
        
		/**
		 * Add form fields to the widget which will be displayed in the WordPress admin area.
		 */
		public function form( $instance ) {
			$defaults = array(
                'title'  => esc_html__( 'Social', 'ef-practical' ),
				'target' => 0,
                'show'   => 'icon',
				'socials' => array(
					'facebook' => array(
						'name' => esc_html__( 'Facebook', 'ef-practical' ),
						'url'  => '',
					),
				    'twitter' => array(
						'name' => esc_html__( 'Twitter', 'ef-practical' ),
						'url'  => '',
					),
                    'googleplus' => array(
						'name' => esc_html__( 'Google-Plus', 'ef-practical' ),
						'url'  => '',
					),
                    'youtube' => array(
						'name' => esc_html__( 'Youtube', 'ef-practical' ),
						'url'  => '',
					),
                    'pinterest'	=> array(
						'name' => esc_html__( 'Pinterest', 'ef-practical' ),
						'url'  => '',
					),
					'instagram'	=> array(
						'name' => esc_html__( 'Instagram', 'ef-practical' ),
						'url'  => '',
					),
					'linkedin' => array(
						'name' => esc_html__( 'LinkedIn', 'ef-practical' ),
						'url'  => '',
					),
					'flickr' => array(
						'name' => esc_html__( 'Flickr', 'ef-practical' ),
						'url'  => '',
					),
					'rss' => array(
						'name' => esc_html__( 'RSS', 'ef-practical' ),
						'url'  => '',
					),
				),
			);
			
			$instance = wp_parse_args( ( array ) $instance, $defaults ); ?>
            
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>">
                <?php esc_attr_e( 'Title', 'ef-practical' ); ?>
                :</label>
            <input class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $instance['title'] ); ?>" />
        </p>
        <p>
            <input id="<?php echo $this->get_field_id( 'target' ); /* WPCS: xss ok. */ ?>" name="<?php echo $this->get_field_name( 'target' ); /* WPCS: xss ok. */ ?>" type="checkbox" value="1" <?php checked( '1', $instance['target'] ); ?>/>
            <label for="<?php echo $this->get_field_id( 'target' ); /* WPCS: xss ok. */ ?>"><?php esc_html_e( 'Check to open in a new window', 'ef-practical' ); ?></label>
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'show' ) ); ?>">
                <?php esc_html_e( 'show :', 'ef-practical' ); ?>
            </label>
            <select class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'show' ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'show' ) ); ?>">
                <option value="icon" <?php selected( $instance[ 'show'], 'icon' ); ?>>
                <?php esc_html_e( 'Icon', 'ef-practical' ); ?>
                </option>
                <option value="text" <?php selected( $instance[ 'show'], 'text' ); ?>>
                <?php esc_html_e( 'Text', 'ef-practical' ); ?>
                </option>
                <option value="icon-text" <?php selected( $instance[ 'show'], 'icon-text' ); ?>>
                <?php esc_html_e( 'Icon - Text', 'ef-practical' ); ?>
                </option>
            </select>
        </p>
        
        <?php
            // field names and id
            $social_field_id   = $this->get_field_id( 'socials' );
            $social_field_name = $this->get_field_name( 'socials' );
        ?>
        <h3 style="margin:20px 0 0 0;">
            <?php esc_attr_e( 'Social Links', 'ef-practical' ); ?>
        </h3>
        <ul id="<?php echo esc_attr( $social_field_id ); ?>">
            <input type="hidden" id="<?php echo esc_attr( $social_field_name ); ?>" value="<?php echo esc_attr( $social_field_name ); ?>">
            <?php
                $socials_show = isset ( $instance['socials'] ) ? $instance['socials']: '';
                if ( ! empty( $socials_show ) ) {
                    foreach( $socials_show as $key => $network ) {
                        $link = isset( $network['url'] ) ? $network['url'] : 0;
                        $name = isset( $network['name'] )  ? $network['name'] : '';
            ?>
                <li id="<?php echo esc_attr( $social_field_id ); ?>_0<?php echo esc_attr( $key ); ?>">
                    <p>
                        <label for="<?php echo esc_attr( $social_field_id ); ?>-<?php echo esc_attr( $key ); ?>-name"><?php echo strip_tags( $name ); /* WPCS: xss ok. */ ?>:</label>
                        <input type="hidden" id="<?php echo esc_attr( $social_field_id ); ?>-<?php echo esc_attr( $key ); ?>-url" name="<?php echo esc_attr( $social_field_name .'['.$key.'][name]' ); ?>" value="<?php echo esc_attr( $name ); ?>">
                        <input type="url" class="widefat" id="<?php echo esc_attr( $social_field_id ); ?>-<?php echo esc_attr( $key ); ?>-url" name="<?php echo esc_attr( $social_field_name .'['.$key.'][url]' ); ?>" value="<?php echo esc_attr( $link ); ?>" />
                    </p>
                </li>
            <?php
                    }
                }
            ?>
        </ul>
<?php
		}
	}
}